<?php
if ( !defined( 'myCRED_VERSION' ) ) exit;
// Subscription Related Hooks
include_once( myCRED_MODULES_DIR . 'mycred-module-subscriptions.php' );
// Third-Party Plugin Hooks
require_once( myCRED_MODULES_DIR . 'mycred-module-plugins.php' );
/**
 * myCRED_Hooks class
 * @since 0.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hooks' ) ) {
	class myCRED_Hooks extends myCRED_Module {

		/**
		 * Construct
		 */
		function __construct() {
			parent::__construct( 'myCRED_Hooks', array(
				'module_name' => 'hooks',
				'option_id'   => 'mycred_pref_hooks',
				'defaults'    => array(
					'installed'   => array(),
					'active'      => array(),
					'hook_prefs'  => array()
				),
				'labels'      => array(
					'menu'        => __( 'Hooks', 'mycred' ),
					'page_title'  => __( 'Hooks', 'mycred' ),
					'page_header' => __( 'Hooks', 'mycred' )
				),
				'screen_id'   => 'myCRED_page_hooks',
				'accordion'   => true,
				'menu_pos'    => 20
			) );
		}

		/**
		 * Load Hooks
		 * @since 0.1
		 * @version 1.0
		 */
		public function module_init() {
			if ( !empty( $this->installed ) ) {
				foreach ( $this->installed as $key => $gdata ) {
					if ( $this->is_active( $key ) && isset( $gdata['callback'] ) ) {
						$this->call( 'run', $gdata['callback'] );
					}
				}
			}
		}

		/**
		 * Call
		 * Either runs a given class method or function.
		 * @since 0.1
		 * @version 1.0
		 */
		public function call( $call, $callback, $return = NULL ) {
			// Class
			if ( is_array( $callback ) && class_exists( $callback[0] ) ) {
				$class = $callback[0];
				$methods = get_class_methods( $class );
				if ( in_array( $call, $methods ) ) {
					$new = new $class( ( isset( $this->hook_prefs ) ) ? $this->hook_prefs : array() );
					return $new->$call( $return );
				}
			}

			// Function
			if ( !is_array( $callback ) ) {
				if ( function_exists( $callback ) ) {
					if ( $return !== NULL )
						return call_user_func( $callback, $return, $this );
					else
						return call_user_func( $callback, $this );
				}
			}
		}

		/**
		 * Get Hooks
		 * @since 0.1
		 * @version 1.1
		 */
		public function get( $save = false ) {
			// Registrations
			$installed['registration'] = array(
				'title'        => __( '%plural% for registrations', 'mycred' ),
				'description'  => __( 'Award %_plural% for users joining your website.', 'mycred' ),
				'callback'     => array( 'myCRED_Hook_Registration' )
			);

			// Logins
			$installed['logging_in'] = array(
				'title'       => __( '%plural% for logins', 'mycred' ),
				'description' => __( 'Award %_plural% for logging in to your website. You can also set an optional limit.', 'mycred' ),
				'callback'    => array( 'myCRED_Hook_Logging_In' )
			);

			// Content Publishing
			$installed['publishing_content'] = array(
				'title'       => __( '%plural% for publishing content', 'mycred' ),
				'description' => __( 'Award %_plural% for publishing content on your website. If your custom post type is not shown bellow, make sure it is set to "Public".', 'mycred' ),
				'callback'    => array( 'myCRED_Hook_Publishing_Content' )
			);

			// Commenting
			$installed['comments'] = array(
				'title'       => __( '%plural% for comments', 'mycred' ),
				'description' => __( 'Award %_plural% for making comments.', 'mycred' ),
				'callback'    => array( 'myCRED_Hook_Comments' )
			);

			// Link Clicks
			$installed['link_click'] = array(
				'title'       => __( '%plural% for clicking on links', 'mycred' ),
				'description' => __( 'Award %_plural% to users who clicks on links generated by the [mycred_link] shortcode.', 'mycred' ),
				'callback'    => array( 'myCRED_Hook_Click_Links' )
			);
			
			// Prep for bbPress
			if ( class_exists( 'bbPress' ) ) {
				$installed['hook_bbpress'] = array(
					'title'       => __( 'bbPress' ),
					'description' => __( 'Awards %_plural% for bbPress actions.', 'mycred' ),
					'callback'    => array( 'myCRED_bbPress' )
				);
			}

			// Prep for Invite Anyone Plugin
			if ( function_exists( 'invite_anyone_init' ) ) {
				$installed['invite_anyone'] = array(
					'title'       => __( 'Invite Anyone Plugin', 'mycred' ),
					'description' => __( 'Awards %_plural% for sending invitations and/or %_plural% if the invite is accepted.', 'mycred' ),
					'callback'    => array( 'myCRED_Invite_Anyone' )
				);
			}

			// Prep for Contact Form 7
			if ( function_exists( 'wpcf7' ) ) {
				$installed['contact_form7'] = array(
					'title'       => __( 'Contact Form 7 Form Submissions', 'mycred' ),
					'description' => __( 'Awards %_plural% for successful form submissions (by logged in users).', 'mycred' ),
					'callback'    => array( 'myCRED_Contact_Form7' )
				);
			}

			// Prep for Jetpack
			if ( class_exists( 'Jetpack' ) ) {
				$installed['jetpack'] = array(
					'title'       => __( 'Jetpack Subscriptions', 'mycred' ),
					'description' => __( 'Awards %_plural% for users signing up for site or comment updates using Jetpack.', 'mycred' ),
					'callback'    => array( 'myCRED_Hook_Jetpack' )
				);
			}

			// Prep for BadgeOS
			if ( class_exists( 'BadgeOS' ) ) {
				$installed['badgeos'] = array(
					'title'       => __( 'BadgeOS', 'mycred' ),
					'description' => __( 'Default settings for each BadgeOS Achievement type. These settings may be overridden for individual achievement type.', 'mycred' ),
					'callback'    => array( 'myCRED_Hook_BadgeOS' )
				);
			}

			// Prep for WP-Polls
			if ( function_exists( 'vote_poll' ) ) {
				$installed['wppolls'] = array(
					'title'       => __( 'WP-Polls', 'mycred' ),
					'description' => __( 'Awards %_plural% for users voting in polls.', 'mycred' ),
					'callback'    => array( 'myCRED_Hook_WPPolls' )
				);
			}

			// WP Favorite Posts
			if ( function_exists( 'wp_favorite_posts' ) ) {
				$installed['wpfavorite'] = array(
					'title'       => __( 'WP Favorite Posts', 'mycred' ),
					'description' => __( 'Awards %_plural% for users adding posts to their favorites.', 'mycred' ),
					'callback'    => array( 'myCRED_Hook_WPFavorite' )
				);
			}

			// Events Manager
			if ( function_exists( 'bp_em_init' ) ) {
				$installed['eventsmanager'] = array(
					'title'       => __( 'Events Manager', 'mycred' ),
					'description' => __( 'Awards %_plural% for users attending events.', 'mycred' ),
					'callback'    => array( 'myCRED_Hook_Events_Manager' )
				);
			}

			$installed = apply_filters( 'mycred_setup_hooks', $installed );

			if ( $save === true && $this->core->can_edit_plugin() ) {
				$new_data = array(
					'active'     => $this->active,
					'installed'  => $installed,
					'hook_prefs' => $this->hook_prefs
				);
				update_option( 'mycred_pref_hooks', $new_data );
			}

			$this->installed = $installed;
			return $installed;
		}

		/**
		 * Admin Page
		 * @since 0.1
		 * @version 1.0
		 */
		public function admin_page() {
			// Security
			if ( !$this->core->can_edit_plugin( get_current_user_id() ) ) wp_die( __( 'Access Denied' ) );

			// Get installed
			$installed = $this->get( true );

			// Message
			if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true ) {
				echo '<div class="updated settings-error"><p>' . __( 'Settings Updated', 'mycred' ) . '</p></div>';
			} ?>

	<div class="wrap" id="myCRED-wrap">
		<div id="icon-myCRED" class="icon32"><br /></div>
		<h2><?php echo apply_filters( 'mycred_label', myCRED_NAME ) . ' ' . __( 'Hooks', 'mycred' ); ?></h2>
		<p><?php echo $this->core->template_tags_general( __( 'Hooks are instances where %_plural% are awarded or deducted from a user, depending on their actions around your website.', 'mycred' ) ); ?></p>
		<form method="post" action="options.php">
			<?php settings_fields( 'myCRED-hooks' ); ?>

			<!-- Loop though Hooks -->
			<div class="list-items expandable-li" id="accordion">
<?php		if ( !empty( $installed ) ) {
				foreach ( $installed as $key => $data ) { ?>

				<h4 class="<?php if ( $this->is_active( $key ) ) echo 'active'; else echo 'inactive'; ?>"><label><?php echo $this->core->template_tags_general( $data['title'] ); ?></label></h4>
				<div class="body" style="display:none;">
					<p><?php echo nl2br( $this->core->template_tags_general( $data['description'] ) ); ?></p>
					<label class="subheader"><?php _e( 'Enable', 'mycred' ); ?></label>
					<ol>
						<li>
							<input type="checkbox" name="mycred_pref_hooks[active][]" id="mycred-hook-<?php echo $key; ?>" value="<?php echo $key; ?>"<?php if ( $this->is_active( $key ) ) echo ' checked="checked"'; ?> />
						</li>
					</ol>
					<?php echo $this->call( 'preferences', $data['callback'] ); ?>

				</div>
<?php			}
			} ?>

			</div>
			<?php submit_button( __( 'Update Changes', 'mycred' ), 'primary large' ); ?>

		</form>
	</div>
<?php		unset( $installed );
			unset( $this );
		}

		/**
		 * Sanititze Settings
		 * @since 0.1
		 * @version 1.0
		 */
		public function sanitize_settings( $post ) {
			// Loop though all installed hooks
			$installed = $this->get();

			// Construct new settings
			$new_post['installed'] = $installed;
			$new_post['active'] = $post['active'];

			if ( !empty( $installed ) ) {
				foreach ( $installed as $key => $data ) {
					if ( isset( $data['callback'] ) && isset( $post['hook_prefs'][$key] ) ) {
						// Old settings
						$old_settings = $post['hook_prefs'][$key];
						
						// New settings
						$new_settings = $this->call( 'sanitise_preferences', $data['callback'], $old_settings );
						
						// If something went wrong use the old settings
						if ( empty( $new_settings ) || $new_settings === NULL || !is_array( $new_settings ) )
							$new_post['hook_prefs'][$key] = $old_settings;
						// Else we got ourselves new settings
						else
							$new_post['hook_prefs'][$key] = $new_settings;
					}
				}
			}

			return $new_post;
		}
	}
}

/**
 * Hook for registrations
 * @since 0.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hook_Registration' ) ) {
	class myCRED_Hook_Registration extends myCRED_Hook {

		/**
		 * Construct
		 */
		function __construct( $hook_prefs ) {
			parent::__construct( array(
				'id'       => 'registration',
				'defaults' => array(
					'creds'   => 10,
					'log'     => '%plural% for becoming a member'
				)
			), $hook_prefs );
		}

		/**
		 * Run
		 * @since 0.1
		 * @version 1.0
		 */
		public function run() {
			if ( $this->prefs['creds'] != 0 )
				add_action( 'user_register', array( $this, 'registration' ) );
		}

		/**
		 * Registration Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function registration( $user_id ) {
			// Make sure user is not excluded
			if ( $this->core->exclude_user( $user_id ) === true ) return;

			// Execute
			$this->core->add_creds(
				'registration',
				$user_id,
				$this->prefs['creds'],
				$this->prefs['log'],
				$user_id,
				array( 'ref_type' => 'user' )
			);
		}

		/**
		 * Preference for Registration Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function preferences() {
			$prefs = $this->prefs; ?>

					<label class="subheader"><?php echo $this->core->plural(); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->format_number( $prefs['creds'] ); ?>" size="8" /></div>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" value="<?php echo $prefs['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, User', 'mycred' ); ?></span>
						</li>
					</ol>
<?php		unset( $this );
		}
	}
}

/**
 * Hook for loggins
 * @since 0.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hook_Logging_In' ) ) {
	class myCRED_Hook_Logging_In extends myCRED_Hook {

		/**
		 * Construct
		 */
		function __construct( $hook_prefs ) {
			parent::__construct( array(
				'id'       => 'logging_in',
				'defaults' => array(
					'creds'   => 1,
					'log'     => '%plural% for logging in',
					'limit'   => 'daily'
				)
			), $hook_prefs );
		}

		/**
		 * Run
		 * @since 0.1
		 * @version 1.1
		 */
		public function run() {
			if ( $this->prefs['creds'] != 0 )
				add_action( 'wp_login', array( $this, 'logging_in' ), 10, 2 );
		}

		/**
		 * Login Hook
		 * @since 0.1
		 * @version 1.1
		 */
		public function logging_in( $user_login, $user ) {
			// Check for exclusion
			if ( $this->core->exclude_user( $user->ID ) === true ) return;

			// Check if we should reward
			if ( !$this->reward_login( $user->ID ) ) return;

			// Execute
			$this->core->add_creds(
				'logging_in',
				$user->ID,
				$this->prefs['creds'],
				$this->prefs['log']
			);
		}

		/**
		 * Reward Login Check
		 * Checks to see if the given user id should be rewarded for logging in.
		 * @returns true or false
		 * @since 1.0.6
		 * @version 1.1
		 */
		protected function reward_login( $user_id ) {
			$now = date_i18n( 'U' );
			$today = date_i18n( 'Y-m-d' );
			$past = get_user_meta( $user_id, 'mycred_last_login', true );

			// Even if there is no limit set we will always impose a 1 min limit
			// to prevent users from just logging in and out for points.
			if ( $past >= $now-apply_filters( 'mycred_hook_login_min_limit', 60 ) ) return false;

			// If limit is set
			if ( !empty( $this->prefs['limit'] ) ) {
				// If logged in before
				if ( !empty( $past ) ) {
					if ( $this->prefs['limit'] == 'twentyfour' ) {
						$mark = 86400;
						$next = $past+$mark;
						// Check if next time we can get points is in future; if thats the case, bail
						if ( $next > $now ) return false;
					}
					elseif ( $this->prefs['limit'] == 'twelve' ) {
						$mark = 43200;
						$next = $past+$mark;
						// Check if next time we can get points is in future; if thats the case, bail
						if ( $next > $now ) return false;
					}
					elseif ( $this->prefs['limit'] == 'sevendays' ) {
						$mark = 604800;
						$next = $past+$mark;
						// Check if next time we can get points is in future; if thats the case, bail
						if ( $next > $now ) return false;
					}
					elseif ( $this->prefs['limit'] == 'daily' ) {
						if ( $today == $past ) return false;
					}
				}
			}

			// Update new login time
			if ( $this->prefs['limit'] == 'daily' )
				update_user_meta( $user_id, 'mycred_last_login', $today );
			else
				update_user_meta( $user_id, 'mycred_last_login', $now );

			return true;
		}

		/**
		 * Preference for Login Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function preferences() {
			$prefs = $this->prefs; ?>

					<label class="subheader"><?php echo $this->core->plural(); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->format_number( $prefs['creds'] ); ?>" size="8" /></div>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log Template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" value="<?php echo $prefs['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Limit', 'mycred' ); ?></label>
					<ol>
						<li>
							<?php $this->impose_limits_dropdown( 'limit' ); ?>

						</li>
					</ol>
<?php		unset( $this );
		}
	}
}

/**
 * Hook for publishing content
 * @since 0.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hook_Publishing_Content' ) ) {
	class myCRED_Hook_Publishing_Content extends myCRED_Hook {

		/**
		 * Construct
		 */
		function __construct( $hook_prefs ) {
			parent::__construct( array(
				'id'       => 'publishing_content',
				'defaults' => array(
					'post'    => array(
						'creds'  => 1,
						'log'    => '%plural% for new Post'
					),
					'page'    => array(
						'creds'  => 1,
						'log'    => '%plural% for new Page'
					)
				)
			), $hook_prefs );
		}

		/**
		 * Run
		 * @since 0.1
		 * @version 1.0
		 */
		public function run() {
			add_action( 'transition_post_status', array( $this, 'publishing_content' ), 10, 3 );
		}

		/**
		 * Publish Content Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function publishing_content( $new_status, $old_status, $post ) {
			$user_id = $post->post_author;
			if ( $this->core->exclude_user( $user_id ) === true ) return;

			$post_id = $post->ID;
			$post_type = $post->post_type;
			if ( !isset( $this->prefs[$post_type]['creds'] ) ) return;
			if ( empty( $this->prefs[$post_type]['creds'] ) || $this->prefs[$post_type]['creds'] == 0 ) return;

			// We want to fire when content get published or when it gets privatly published
			$status = apply_filters( 'mycred_publish_hook_old', array( 'new', 'auto-draft', 'draft', 'private', 'pending' ) );
			if ( in_array( $old_status, $status ) && $new_status == 'publish' && array_key_exists( $post_type, $this->prefs ) ) {

				// Make sure this is unique
				if ( $this->has_entry( 'publishing_content', $post_id, $user_id ) ) return;

				// Prep
				$entry = $this->prefs[$post_type]['log'];
				$data = array( 'ref_type' => 'post' );

				// Add Creds
				$this->core->add_creds(
					'publishing_content',
					$user_id,
					$this->prefs[$post_type]['creds'],
					$entry,
					$post_id,
					$data
				);
			}
		}

		/**
		 * Preference for Publish Content Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function preferences() {
			$prefs = $this->prefs; ?>

					<label class="subheader"><?php echo $this->core->template_tags_general( __( '%plural% for Posts', 'mycred' ) ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'post' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'post' => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $prefs['post']['creds'] ); ?>" size="8" /></div>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'post' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'post' => 'log' ) ); ?>" value="<?php echo $prefs['post']['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Post', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader"><?php echo $this->core->template_tags_general( __( '%plural% for Pages', 'mycred' ) ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'page' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'page' => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $prefs['page']['creds'] ); ?>" size="8" /></div>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'page' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'page' => 'log' ) ); ?>" value="<?php echo $prefs['page']['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Post', 'mycred' ); ?></span>
						</li>
					</ol>
<?php		// Get all not built-in post types (excludes posts, pages, media)
			$post_type_args = array(
				'public'   => true,
				'_builtin' => false
			);
			$post_types = get_post_types( $post_type_args, 'objects', 'and' ); 
			foreach ( $post_types as $post_type ) {
				// Start by checking if this post type should be excluded
				if ( !$this->include_post_type( $post_type->name ) ) continue;

				// Points to award/deduct
				if ( isset( $prefs[$post_type->name]['creds'] ) )
					$_creds = $prefs[$post_type->name]['creds'];
				else
					$_creds = 0;

				// Log template
				if ( isset( $prefs[$post_type->name]['log'] ) )
					$_log = $prefs[$post_type->name]['log'];
				else
					$_log = ''; ?>

					<label class="subheader"><?php echo sprintf( $this->core->template_tags_general( __( '%plural% for %s', 'mycred' ) ),  $post_type->labels->name ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( $post_type->name => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( $post_type->name => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $_creds ); ?>" size="8" /></div>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( $post_type->name => 'log' ) ); ?>" id="<?php echo $this->field_id( array( $post_type->name => 'log' ) ); ?>" value="<?php echo $_log; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Post', 'mycred' ); ?></span>
						</li>
					</ol>
<?php		}
			unset( $this );
		}

		/**
		 * Include Post Type
		 * Checks if a given post type should be excluded
		 * @since 0.1
		 * @version 1.1
		 */
		protected function include_post_type( $post_type ) {
			// Exclude Core
			$excludes = array( 'post', 'page' );
			
			// Prep for bbPress
			if ( class_exists( 'bbPress' ) ) {
				$excludes[] = bbp_get_forum_post_type();
				$excludes[] = bbp_get_topic_post_type();
				$excludes[] = bbp_get_reply_post_type();
			}
			
			// Prep for BadgeOS
			if ( function_exists( 'badgeos_get_achievement_types_slugs' ) ) {
				$excludes = array_merge( $excludes, badgeos_get_achievement_types_slugs() );
			}
			
			if ( in_array( $post_type, apply_filters( 'mycred_post_type_excludes', $excludes ) ) ) return false;
			return true;
		}
	}
}

/**
 * Hook for comments
 * @since 0.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hook_Comments' ) ) {
	class myCRED_Hook_Comments extends myCRED_Hook {

		/**
		 * Construct
		 */
		function __construct( $hook_prefs ) {
			parent::__construct( array(
				'id'       => 'comments',
				'defaults' => array(
					'limits'   => array(
						'self_reply' => 0,
						'per_post'   => 10,
						'per_day'    => 0
					),
					'approved' => array(
						'creds'   => 1,
						'log'     => '%plural% for Approved Comment'
					),
					'spam'     => array(
						'creds'   => '-5',
						'log'     => '%plural% deduction for Comment marked as SPAM'
					),
					'trash'    => array(
						'creds'   => '-1',
						'log'     => '%plural% deduction for deleted / unapproved Comment'
					)
				)
			), $hook_prefs );
		}

		/**
		 * Run
		 * @since 0.1
		 * @version 1.0
		 */
		public function run() {
			add_action( 'comment_post',                       array( $this, 'new_comment' ), 10, 2 );

			if ( $this->prefs['approved'] != 0 ) {
				add_action( 'comment_unapproved_to_approved', array( $this, 'approved_comments' ) );
				add_action( 'comment_trash_to_approved',      array( $this, 'approved_comments' ) );
				add_action( 'comment_spam_to_approved',       array( $this, 'approved_comments' ) );
			}

			if ( $this->prefs['spam'] != 0 ) {
				add_action( 'comment_approved_to_spam',       array( $this, 'spam_comments' ) );
				add_action( 'comment_unapproved_to_spam',     array( $this, 'spam_comments' ) );
			}

			if ( $this->prefs['trash'] != 0 ) {
				add_action( 'comment_approved_to_unapproved', array( $this, 'trash_comments' ) );
				add_action( 'comment_approved_to_trash',      array( $this, 'trash_comments' ) );
				add_action( 'comment_unapproved_to_trash',    array( $this, 'trash_comments' ) );
			}
		}

		/**
		 * New Comment
		 * If comments are approved without moderation, we apply the corresponding method
		 * or else we will wait till the appropriate instance.
		 *
		 * @since 0.1
		 * @version 1.0
		 */
		public function new_comment( $comment_id, $comment_status ) {
			// Marked SPAM
			if ( $comment_status === 'spam' && $this->prefs['spam'] != 0 )
				$this->spam_comments( $comment_id );
			// Approved comment
			elseif ( $comment_status == '1' && $this->prefs['approved'] != 0 )
				$this->approved_comments( $comment_id );

			// All else comments are moderated and we will award / deduct points in a different instance
			return;
		}

		/**
		 * Approved Comments
		 * Validate and execute our settings for approved comments.
		 *
		 * @since 0.1
		 * @version 1.0
		 */
		public function approved_comments( $comment ) {
			// Passing an integer instead of an object means we need to grab the comment object ourselves
			if ( !is_object( $comment ) )
				$comment = get_comment( $comment );

			// Logged out users miss out
			if ( $comment->user_id == 0 ) return;

			// Check if user should be excluded
			if ( $this->core->exclude_user( $comment->user_id ) === true ) return;

			// Make sure this is unique event
			if ( $this->has_entry( 'approved_comment', $comment->comment_ID, $comment->user_id ) ) return;

			// Check if we are allowed to comment our own comment
			if ( $this->prefs['limits']['self_reply'] != 0 && $comment->comment_parent != 0 ) {
				$parent = get_comment( $comment->comment_parent );
				if ( $parent->user_id == $comment->user_id ) return;
			}

			// Enforce limits
			if ( $this->user_exceeds_limit( $comment->user_id, $comment->comment_post_ID ) ) return;

			// Execute
			$this->core->add_creds(
				'approved_comment',
				$comment->user_id,
				$this->prefs['approved']['creds'],
				$this->prefs['approved']['log'],
				$comment->comment_ID,
				array( 'ref_type' => 'comment' )
			);
		}

		/**
		 * SPAM Comments
		 * Validate and execute our settings for comments marked as SPAM.
		 *
		 * @since 0.1
		 * @version 1.0
		 */
		public function spam_comments( $comment ) {
			// Passing an integer instead of an object means we need to grab the comment object ourselves
			if ( !is_object( $comment ) )
				$comment = get_comment( $comment );

			// Logged out users miss out
			if ( $comment->user_id == 0 ) return;

			// Check if user should be excluded
			if ( $this->core->exclude_user( $comment->user_id ) === true ) return;

			// Make sure this is unique event
			if ( $this->has_entry( 'spam_comment', $comment->comment_ID, $comment->user_id ) ) return;

			// Execute
			$this->core->add_creds(
				'spam_comment',
				$comment->user_id,
				$this->prefs['spam']['creds'],
				$this->prefs['spam']['log'],
				$comment->comment_ID,
				array( 'ref_type' => 'comment' )
			);
		}

		/**
		 * Trashed Comments
		 * Validate and execute our settings for trashed or unapproved comments.
		 *
		 * @since 0.1
		 * @version 1.0
		 */
		public function trash_comments( $comment ) {
			// Passing an integer instead of an object means we need to grab the comment object ourselves
			if ( !is_object( $comment ) )
				$comment = get_comment( $comment );

			// Logged out users miss out
			if ( $comment->user_id == 0 ) return;

			// Check if user should be excluded
			if ( $this->core->exclude_user( $comment->user_id ) === true ) return;

			// Make sure this is unique event
			if ( $this->has_entry( 'deleted_comment', $comment->comment_ID, $comment->user_id ) ) return;

			// Execute
			$this->core->add_creds(
				'deleted_comment',
				$comment->user_id,
				$this->prefs['trash']['creds'],
				$this->prefs['trash']['log'],
				$comment->comment_ID,
				array( 'ref_type' => 'comment' )
			);
		}
		
		/**
		 * Check if user exceeds limit
		 * @since 1.1.1
		 * @version 1.0
		 */
		public function user_exceeds_limit( $user_id = NULL, $post_id = NULL ) {
			if ( !isset( $this->prefs['limits'] ) ) return false;

			// Prep
			$today = date_i18n( 'Y-m-d' );

			// First we check post limit
			if ( $this->prefs['limits']['per_post'] > 0 ) {
				$post_limit = 0;
				// Grab limit
				$limit = get_user_meta( $user_id, 'mycred_comment_limit_post', true );
				// Apply default if none exist
				if ( empty( $limit ) ) $limit = array( $post_id => $post_limit );

				// Check if post_id is in limit array
				if ( array_key_exists( $post_id, $limit ) ) {
					$post_limit = $limit[$post_id];

					// Limit is reached
					if ( $post_limit >= $this->prefs['limits']['per_post'] ) return true;
				}

				// Add / Replace post_id counter with an incremented value
				$limit[$post_id] = $post_limit+1;
				// Save
				update_user_meta( $user_id, 'mycred_comment_limit_post', $limit );
			}

			// Second we check daily limit
			if ( $this->prefs['limits']['per_day'] > 0 ) {
				$daily_limit = 0;
				// Grab limit
				$limit = get_user_meta( $user_id, 'mycred_comment_limit_day', true );
				// Apply default if none exist
				if ( empty( $limit ) ) $limit = array();

				// Check if todays date is in limit
				if ( array_key_exists( $today, $limit ) ) {
					$daily_limit = $limit[$today];

					// Limit is reached
					if ( $daily_limit >= $this->prefs['limits']['per_day'] ) return true;
				}
				// Today is not in limit array so we reset to remove other dates
				else {
					$limit = array();
				}

				// Add / Replace todays counter with an imcremented value
				$limit[$today] = $daily_limit+1;
				// Save
				update_user_meta( $user_id, 'mycred_comment_limit_day', $limit );
			}

			return false;
		}

		/**
		 * Preferences for Commenting Hook
		 * @since 0.1
		 * @version 1.0
		 */
		public function preferences() {
			$prefs = $this->prefs;

			if ( !isset( $prefs['limits'] ) )
				$prefs['limits'] = array(
					'self_reply' => 0,
					'per_post'   => 10,
					'per_day'    => 0
				); ?>

					<label class="subheader" for="<?php echo $this->field_id( array( 'approved' => 'creds' ) ); ?>"><?php _e( 'Approved Comment', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'approved' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'approved' => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $prefs['approved']['creds'] ); ?>" size="8" /></div>
						</li>
						<li class="empty">&nbsp;</li>
						<li>
							<label for="<?php echo $this->field_id( array( 'approved' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'approved' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'approved' => 'log' ) ); ?>" value="<?php echo $prefs['approved']['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Comment', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader" for="<?php echo $this->field_id( array( 'spam' => 'creds' ) ); ?>"><?php _e( 'Comment Marked SPAM', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'spam' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'spam' => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $prefs['spam']['creds'] ); ?>" size="8" /></div>
						</li>
						<li class="empty">&nbsp;</li>
						<li>
							<label for="<?php echo $this->field_id( array( 'spam' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'spam' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'spam' => 'log' ) ); ?>" value="<?php echo $prefs['spam']['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Comment', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader" for="<?php echo $this->field_id( array( 'trash' => 'creds' ) ); ?>"><?php _e( 'Trashed / Unapproved Comments', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'trash' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'trash' => 'creds' ) ); ?>" value="<?php echo $this->core->format_number( $prefs['trash']['creds'] ); ?>" size="8" /></div>
						</li>
						<li class="empty">&nbsp;</li>
						<li>
							<label for="<?php echo $this->field_id( array( 'trash' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'trash' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'trash' => 'log' ) ); ?>" value="<?php echo $prefs['trash']['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General, Comment', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Limits', 'mycred' ); ?></label>
					<ol>
						<li>
							<label for="<?php echo $this->field_id( array( 'limits' => 'per_post' ) ); ?>"><?php _e( 'Limit per post', 'mycred' ); ?></label>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'limits' => 'per_post' ) ); ?>" id="<?php echo $this->field_id( array( 'limits' => 'per_post' ) ); ?>" value="<?php echo $prefs['limits']['per_post']; ?>" size="8" /></div>
							<span class="description"><?php echo $this->core->template_tags_general( __( 'The number of comments per post that grants %_plural%. User zero for unlimited.', 'mycred' ) ); ?></span>
						</li>
						<li class="empty">&nbsp;</li>
						<li>
							<label for="<?php echo $this->field_id( array( 'limits' => 'per_day' ) ); ?>"><?php _e( 'Limit per day', 'mycred' ); ?></label>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'limits' => 'per_day' ) ); ?>" id="<?php echo $this->field_id( array( 'limits' => 'per_day' ) ); ?>" value="<?php echo $prefs['limits']['per_day']; ?>" size="8" /></div>
							<span class="description"><?php echo $this->core->template_tags_general( __( 'Number of comments per day that grants %_plural%. User zero for unlimited.', 'mycred' ) ); ?></span>
						</li>
						<li class="empty">&nbsp;</li>
						<li>
							<input type="checkbox" name="<?php echo $this->field_name( array( 'limits' => 'self_reply' ) ); ?>" id="<?php echo $this->field_id( array( 'limits' => 'self_reply' ) ); ?>" <?php checked( $prefs['limits']['self_reply'], 1 ); ?> value="1" />
							<label for="<?php echo $this->field_id( array( 'limits' => 'self_reply' ) ); ?>"><?php echo $this->core->template_tags_general( __( '%plural% is to be awarded even when comment authors reply to their own comment.', 'mycred' ) ); ?></label>
						</li>
					</ol>
<?php		unset( $this );
		}
		
		/**
		 * Sanitise Preference
		 * @since 1.1.1
		 * @version 1.0
		 */
		function sanitise_preferences( $data ) {
			$new_data = $data;

			$new_data['limits']['per_post'] = ( !empty( $data['limits']['per_post'] ) ) ? abs( $data['limits']['per_post'] ) : 0;
			$new_data['limits']['per_day'] = ( !empty( $data['limits']['per_day'] ) ) ? abs( $data['limits']['per_day'] ) : 0;
			$new_data['limits']['self_reply'] = ( isset( $data['limits']['self_reply'] ) ) ? $data['limits']['self_reply'] : 0;

			return $new_data;
		}
	}
}
/**
 * Hooks for Clicking on Links
 * @since 1.1
 * @version 1.0
 */
if ( !class_exists( 'myCRED_Hook_Click_Links' ) ) {
	class myCRED_Hook_Click_Links extends myCRED_Hook {

		/**
		 * Construct
		 */
		function __construct( $hook_prefs ) {
			parent::__construct( array(
				'id'       => 'link_click',
				'defaults' => array(
					'limit_by' => 'none',
					'creds'    => 1,
					'log'      => '%plural% for clicking on link to: %url%'
				)
			), $hook_prefs );
		}

		/**
		 * Run
		 * @since 1.1
		 * @version 1.0
		 */
		public function run() {
			add_action( 'mycred_front_enqueue',        array( $this, 'register_script' )       );
			add_action( 'wp_footer',                   array( $this, 'footer' )                );

			add_shortcode( 'mycred_link',              'mycred_render_shortcode_link'          );
			add_action( 'wp_ajax_mycred-click-points', array( $this, 'ajax_call_link_points' ) );

			add_filter( 'mycred_parse_tags_link',      array( $this, 'parse_custom_tags' ), 10, 2 );
		}

		/**
		 * Customize Limit Options
		 * @since 1.1
		 * @version 1.0
		 */
		public function custom_limit() {
			return array(
				'none' => __( 'No limit', 'mycred' ),
				'url'  => __( 'Once for each unique URL', 'mycred' ),
				'id'   => __( 'Once for each unique link id', 'mycred' )
			);
		}

		/**
		 * Parse Custom Tags in Log
		 * @since 1.1
		 * @version 1.0
		 */
		public function parse_custom_tags( $content, $log_entry ) {
			$data = unserialize( $log_entry->data );
			$content = str_replace( '%url%', $data['link_url'], $content );
			$content = str_replace( '%id%',  $data['link_id'], $content );

			return $content;
		}

		/**
		 * Register Script
		 * @since 1.1
		 * @version 1.0
		 */
		public function register_script() {
			wp_register_script(
				'mycred-link-points',
				plugins_url( 'assets/js/links.js', myCRED_THIS ),
				array( 'jquery' ),
				myCRED_VERSION . '.1',
				true
			);

			global $mycred_link_points;
			if ( $mycred_link_points === true ) {
				wp_enqueue_script( 'mycred-link-points' );
			}
		}

		/**
		 * WP Fotter
		 * @since 1.1
		 * @version 1.0
		 */
		public function footer() {
			global $mycred_link_points;
			if ( $mycred_link_points === true ) {
				wp_localize_script(
					'mycred-link-points',
					'myCREDgive',
					array(
						'ajaxurl' => admin_url( 'admin-ajax.php' ),
						'token' => wp_create_nonce( 'mycred-link-points' )
					)
				);
				wp_enqueue_script( 'mycred-link-points' );
			}
		}

		/**
		 * Custom Has Entry Check
		 * @since 1.1
		 * @version 1.0
		 */
		public function has_entry( $action = '', $reference = '' ) {
			global $wpdb;

			if ( $this->prefs['limit_by'] == 'url' ) {
				$string = '%s:8:"link_url";s:' . strlen( $reference ) . ':"' . $reference . '";%';
			}
			elseif ( $this->prefs['limit_by'] == 'id' ) {
				$string = '%s:7:"link_id";s:' . strlen( $reference ) . ':"' . $reference . '";%';
			}
			else return false;

			$sql = "SELECT id FROM " . $wpdb->prefix . 'myCRED_log' . " WHERE ref = %s AND data LIKE %s";
			$wpdb->get_results( $wpdb->prepare( $sql, $action, $string ) );
			if ( $wpdb->num_rows > 0 ) return true;

			return false;
		}

		/**
		 * AJAX Call Handler
		 * @since 1.1
		 * @version 1.0
		 */
		public function ajax_call_link_points() {
			// We must be logged in
			if ( !is_user_logged_in() ) die();

			// Security
			check_ajax_referer( 'mycred-link-points', 'token' );

			// Check if user should be excluded
			if ( $this->core->exclude_user( get_current_user_id() ) === true ) return;

			// If amount is not set we default
			if ( $_POST['amount'] == 0 )
				$amount = $this->prefs['creds'];
			else
				$amount = $this->core->format_number( $_POST['amount'] );

			// Limits
			if ( $this->prefs['limit_by'] == 'url' ) {
				if ( !isset( $_POST['url'] ) || empty( $_POST['url'] ) ) die();
				if ( $this->has_entry( 'link_click', $_POST['url'] ) ) die();
				$ref = $_POST['url'];
			}
			elseif ( $this->prefs['limit_by'] == 'id' ) {
				if ( !isset( $_POST['eid'] ) || empty( $_POST['eid'] ) ) die();
				if ( $this->has_entry( 'link_click', $_POST['eid'] ) ) die();
				$ref = $_POST['eid'];
			}
			else {
				$ref = '';
			}

			// Execute
			$this->core->add_creds(
				'link_click',
				get_current_user_id(),
				$amount,
				$this->prefs['log'],
				$ref,
				array(
					'ref_type' => 'link',
					'link_url' => ( isset( $_POST['url'] ) ) ? $_POST['url'] : '',
					'link_id'  => ( isset( $_POST['eid'] ) ) ? $_POST['eid'] : ''
				)
			);

			// Report the good news
			die( json_encode( 'done' ) );
		}

		/**
		 * Preference for Link Click Hook
		 * @since 1.1
		 * @version 1.0
		 */
		public function preferences() {
			$prefs = $this->prefs; ?>

					<label class="subheader"><?php echo $this->core->plural(); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->format_number( $prefs['creds'] ); ?>" size="8" /></div>
							<span class="description"><?php _e( 'The default amount to award for clicking on links. You can override this in the shortcode.', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Log Template', 'mycred' ); ?></label>
					<ol>
						<li>
							<div class="h2"><input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" value="<?php echo $prefs['log']; ?>" class="long" /></div>
							<span class="description"><?php _e( 'Available template tags: General and custom tags: %url% or %id%.', 'mycred' ); ?></span>
						</li>
					</ol>
					<label class="subheader"><?php _e( 'Limits', 'mycred' ); ?></label>
					<ol>
						<li>
							<?php 
			add_filter( 'mycred_hook_impose_limits', array( $this, 'custom_limit' ) );				
			$this->impose_limits_dropdown( 'limit_by', false ); ?>

						</li>
						<li><strong><?php _e( 'Remember!', 'mycred' ); ?></strong> <?php echo $this->core->template_tags_general( __( 'If you select to limit by id and you do not include the id attribute in the shortcode, no %_plural% will be awarded!', 'mycred' ) ); ?></li>
					</ol>
<?php		unset( $this );
		}
	}
}
?>